@@ -5,21 +5,17 @@ import (
 	"fmt"
 	"os"
 	"path/filepath"
-	"strings"
 
 	"github.com/spf13/pflag"
-	"mvdan.cc/sh/v3/syntax"
 
 	"github.com/go-task/task/v3"
 	"github.com/go-task/task/v3/args"
 	"github.com/go-task/task/v3/errors"
-	"github.com/go-task/task/v3/internal/experiments"
+	"github.com/go-task/task/v3/experiments"
 	"github.com/go-task/task/v3/internal/filepathext"
 	"github.com/go-task/task/v3/internal/flags"
 	"github.com/go-task/task/v3/internal/logger"
-	"github.com/go-task/task/v3/internal/sort"
-	ver "github.com/go-task/task/v3/internal/version"
-	"github.com/go-task/task/v3/taskfile"
+	"github.com/go-task/task/v3/internal/version"
 	"github.com/go-task/task/v3/taskfile/ast"
 )
 
@@ -57,11 +53,12 @@ func run() error {
 		return err
 	}
 
-	dir := flags.Dir
-	entrypoint := flags.Entrypoint
+	if err := experiments.Validate(); err != nil {
+		log.Warnf("%s\n", err.Error())
+	}
 
 	if flags.Version {
-		fmt.Printf("Task version: %s\n", ver.GetVersionWithSum())
+		fmt.Println(version.GetVersionWithBuildInfo())
 		return nil
 	}
 
@@ -79,7 +76,7 @@ func run() error {
 		if err != nil {
 			return err
 		}
-		args, _, err := getArgs()
+		args, _, err := args.Get()
 		if err != nil {
 			return err
 		}
@@ -113,83 +110,29 @@ func run() error {
 		return nil
 	}
 
-	if flags.Global {
-		home, err := os.UserHomeDir()
-		if err != nil {
-			return fmt.Errorf("task: Failed to get user home directory: %w", err)
-		}
-		dir = home
-	}
-
-	if err := experiments.Validate(); err != nil {
-		log.Warnf("%s\n", err.Error())
-	}
-
-	var taskSorter sort.Sorter
-	switch flags.TaskSort {
-	case "none":
-		taskSorter = nil
-	case "alphanumeric":
-		taskSorter = sort.AlphaNumeric
-	}
-
-	e := task.Executor{
-		Dir:         dir,
-		Entrypoint:  entrypoint,
-		Force:       flags.Force,
-		ForceAll:    flags.ForceAll,
-		Insecure:    flags.Insecure,
-		Download:    flags.Download,
-		Offline:     flags.Offline,
-		Timeout:     flags.Timeout,
-		Watch:       flags.Watch,
-		Verbose:     flags.Verbose,
-		Silent:      flags.Silent,
-		AssumeYes:   flags.AssumeYes,
-		Dry:         flags.Dry || flags.Status,
-		Summary:     flags.Summary,
-		Parallel:    flags.Parallel,
-		Color:       flags.Color,
-		Concurrency: flags.Concurrency,
-		Interval:    flags.Interval,
-
-		Stdin:  os.Stdin,
-		Stdout: os.Stdout,
-		Stderr: os.Stderr,
-
-		OutputStyle:        flags.Output,
-		TaskSorter:         taskSorter,
-		EnableVersionCheck: true,
-	}
-	listOptions := task.NewListOptions(flags.List, flags.ListAll, flags.ListJson, flags.NoStatus)
-	if err := listOptions.Validate(); err != nil {
+	e := task.NewExecutor(
+		flags.WithFlags(),
+		task.WithVersionCheck(true),
+	)
+	if err := e.Setup(); err != nil {
 		return err
 	}
 
-	err := e.Setup()
-	if err != nil {
-		return err
-	}
-
-	// If the download flag is specified, we should stop execution as soon as
-	// taskfile is downloaded
-	if flags.Download {
-		return nil
-	}
-
 	if flags.ClearCache {
-		cache, err := taskfile.NewCache(e.TempDir.Remote)
-		if err != nil {
-			return err
-		}
-		return cache.Clear()
-	}
-
-	if (listOptions.ShouldListTasks()) && flags.Silent {
-		return e.ListTaskNames(flags.ListAll)
+		cachePath := filepath.Join(e.TempDir.Remote, "remote")
+		return os.RemoveAll(cachePath)
 	}
 
+	listOptions := task.NewListOptions(
+		flags.List,
+		flags.ListAll,
+		flags.ListJson,
+		flags.NoStatus,
+	)
 	if listOptions.ShouldListTasks() {
+		if flags.Silent {
+			return e.ListTaskNames(flags.ListAll)
+		}
 		foundTasks, err := e.ListTasks(listOptions)
 		if err != nil {
 			return err
@@ -200,17 +143,12 @@ func run() error {
 		return nil
 	}
 
-	var (
-		calls   []*task.Call
-		globals *ast.Vars
-	)
-
-	tasksAndVars, cliArgs, err := getArgs()
+	// Parse the remaining arguments
+	argv, cliArgs, err := args.Get()
 	if err != nil {
 		return err
 	}
-
-	calls, globals = args.Parse(tasksAndVars...)
+	calls, globals := args.Parse(argv...)
 
 	// If there are no calls, run the default task instead
 	if len(calls) == 0 {
@@ -236,24 +174,3 @@ func run() error {
 
 	return e.Run(ctx, calls...)
 }
-
-func getArgs() ([]string, string, error) {
-	var (
-		args          = pflag.Args()
-		doubleDashPos = pflag.CommandLine.ArgsLenAtDash()
-	)
-
-	if doubleDashPos == -1 {
-		return args, "", nil
-	}
-
-	var quotedCliArgs []string
-	for _, arg := range args[doubleDashPos:] {
-		quotedCliArg, err := syntax.Quote(arg, syntax.LangBash)
-		if err != nil {
-			return nil, "", err
-		}
-		quotedCliArgs = append(quotedCliArgs, quotedCliArg)
-	}
-	return args[:doubleDashPos], strings.Join(quotedCliArgs, " "), nil
-}
