@@ -1,7 +1,6 @@
 package taskfile
 
 import (
-	"context"
 	"io"
 	"os"
 	"path/filepath"
@@ -9,6 +8,7 @@ import (
 
 	"github.com/go-task/task/v3/internal/execext"
 	"github.com/go-task/task/v3/internal/filepathext"
+	"github.com/go-task/task/v3/internal/fsext"
 )
 
 // A FileNode is a node that reads a taskfile from the local filesystem.
@@ -20,7 +20,7 @@ type FileNode struct {
 func NewFileNode(entrypoint, dir string, opts ...NodeOption) (*FileNode, error) {
 	var err error
 	base := NewBaseNode(dir, opts...)
-	entrypoint, base.dir, err = resolveFileNodeEntrypointAndDir(entrypoint, base.dir)
+	entrypoint, base.dir, err = fsext.Search(entrypoint, base.dir, defaultTaskfiles)
 	if err != nil {
 		return nil, err
 	}
@@ -34,11 +34,7 @@ func (node *FileNode) Location() string {
 	return node.Entrypoint
 }
 
-func (node *FileNode) Remote() bool {
-	return false
-}
-
-func (node *FileNode) Read(ctx context.Context) ([]byte, error) {
+func (node *FileNode) Read() ([]byte, error) {
 	f, err := os.Open(node.Location())
 	if err != nil {
 		return nil, err
@@ -47,34 +43,6 @@ func (node *FileNode) Read(ctx context.Context) ([]byte, error) {
 	return io.ReadAll(f)
 }
 
-// resolveFileNodeEntrypointAndDir resolves checks the values of entrypoint and dir and
-// populates them with default values if necessary.
-func resolveFileNodeEntrypointAndDir(entrypoint, dir string) (string, string, error) {
-	var err error
-	if entrypoint != "" {
-		entrypoint, err = Exists(entrypoint)
-		if err != nil {
-			return "", "", err
-		}
-		if dir == "" {
-			dir = filepath.Dir(entrypoint)
-		}
-		return entrypoint, dir, nil
-	}
-	if dir == "" {
-		dir, err = os.Getwd()
-		if err != nil {
-			return "", "", err
-		}
-	}
-	entrypoint, err = ExistsWalk(dir)
-	if err != nil {
-		return "", "", err
-	}
-	dir = filepath.Dir(entrypoint)
-	return entrypoint, dir, nil
-}
-
 func (node *FileNode) ResolveEntrypoint(entrypoint string) (string, error) {
 	// If the file is remote, we don't need to resolve the path
 	if strings.Contains(entrypoint, "://") {
@@ -84,7 +52,7 @@ func (node *FileNode) ResolveEntrypoint(entrypoint string) (string, error) {
 		return entrypoint, nil
 	}
 
-	path, err := execext.Expand(entrypoint)
+	path, err := execext.ExpandLiteral(entrypoint)
 	if err != nil {
 		return "", err
 	}
@@ -100,7 +68,7 @@ func (node *FileNode) ResolveEntrypoint(entrypoint string) (string, error) {
 }
 
 func (node *FileNode) ResolveDir(dir string) (string, error) {
-	path, err := execext.Expand(dir)
+	path, err := execext.ExpandLiteral(dir)
 	if err != nil {
 		return "", err
 	}
@@ -114,7 +82,3 @@ func (node *FileNode) ResolveDir(dir string) (string, error) {
 	entrypointDir := filepath.Dir(node.Entrypoint)
 	return filepathext.SmartJoin(entrypointDir, path), nil
 }
-
-func (node *FileNode) FilenameAndLastDir() (string, string) {
-	return "", filepath.Base(node.Entrypoint)
-}
